stock-cli 0.1.0

stock price viewing cli that can show for any ticker that the alpha vantage api supports. You can choose how many days to see price quotes. It graphs prices
stock-cli-0.1.0 is not a library.